@@ -7,7 +7,7 @@ use Mojo::Util qw( camelize );
 #------------------------------------------------------------------------------
 #   Crud 版本信息
 #------------------------------------------------------------------------------
-our $VERSION = '0.0.2';
+our $VERSION = '0.0.3';
 
 #------------------------------------------------------------------------------
 #   Crud 插件注册方法
@@ -51,14 +51,14 @@ sub register {
       # 接收 GET 请求，对应前端数据查询请求
       #------------------------------------------------------
       $resource->get->to('#rest_list')->name("list_$route_part");
-      $app->log->debug( "    GET " . $r->to_string . "/$route_part   (rest_list)" );
+      $app->log->debug( " GET " . $r->to_string . "/$route_part   (rest_list)" );
 
       #------------------------------------------------------
       # 接收 POST 请求，对应前端新增数据请求
       #------------------------------------------------------
       if ( !$readonly ) {
         $resource->post->to('#rest_create')->name("create_$name");
-        $app->log->debug( "   POST " . $r->to_string . "/$route_part   (rest_create)" );
+        $app->log->debug( " POST " . $r->to_string . "/$route_part   (rest_create)" );
       }
 
       #------------------------------------------------------
@@ -79,21 +79,21 @@ sub register {
       # 接收 GET 请求，处理单 id 数据查询
       #------------------------------------------------------
       $resource->get->to("#rest_show")->name("show_$name");
-      $app->log->debug( "    GET " . $r->to_string . "/$route_part/:${name}id   (rest_show)" );
+      $app->log->debug( " GET " . $r->to_string . "/$route_part/:${name}id   (rest_show)" );
 
       if ( !$readonly ) {
 
         #------------------------------------------------------
         # 接收 DELETE 请求，对应前端删除数据请求
         #------------------------------------------------------
-        $resource->delete->to('#rest_remove')->name("delete_$name");
+        $resource->delete->to('#rest_delete')->name("delete_$name");
         $app->log->debug( " DELETE " . $r->to_string . "/$route_part/:${name}id   (rest_delete)" );
 
         #------------------------------------------------------
         # 接收 PUT 请求，对应前端更新数据请求
         #------------------------------------------------------
         $resource->put->to('#rest_update')->name("update_$name");
-        $app->log->debug( "    PUT " . $r->to_string . "/$route_part/:${name}id   (rest_update)" );
+        $app->log->debug( " PUT " . $r->to_string . "/$route_part/:${name}id   (rest_update)" );
       }
 
       #------------------------------------------------------
@@ -105,4 +105,3 @@ sub register {
 }
 
 1;
-
